@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.106.2.3 2009/01/05 17:39:43 raeburn Exp $
+# $Id: lonlogin.pm,v 1.106.4.8 2010/03/31 23:18:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -46,7 +46,7 @@ sub handler {
 	(join('&',$ENV{'QUERY_STRING'},$env{'request.querystring'},
 	      $ENV{'REDIRECT_QUERY_STRING'}),
 	 ['interface','username','domain','firsturl','localpath','localres',
-	  'token']);
+	  'token','role','symb']);
     if (!defined($env{'form.firsturl'})) {
         &Apache::lonacc::get_posted_cgi($r,['firsturl']);
     }
@@ -81,11 +81,15 @@ sub handler {
 	    &Apache::loncommon::start_page('Already logged in');
 	my $end_page = 
 	    &Apache::loncommon::end_page();
+        my $dest = '/adm/roles';
+        if ($env{'form.firsturl'} ne '') {
+            $dest = $env{'form.firsturl'};
+        }
 	$r->print(
                   $start_page
                  .'<h1>'.&mt('You are already logged in!').'</h1>'
-                 .'<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]logout[_4].',
-                  '<a href="/adm/roles">','</a>','<a href="/adm/logout">','</a>').'</p>'
+                 .'<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]log out[_4].',
+                  '<a href="'.$dest.'">','</a>','<a href="/adm/logout">','</a>').'</p>'
                  .'<p><a href="/adm/loginproblems.html">'.&mt('Login problems?').'</a></p>'
                  .$end_page
                  );
@@ -116,7 +120,16 @@ sub handler {
     my $iconpath= 
 	&Apache::loncommon::lonhttpdurl($r->dir_config('lonIconsURL'));
 
+    my $lonhost = $r->dir_config('lonHostID');
     my $domain = &Apache::lonnet::default_login_domain();
+    if ($lonhost ne '') {
+        my $redirect = &check_loginvia($domain,$lonhost);
+        if ($redirect) {
+            $r->print($redirect);
+            return OK;
+        }
+    }
+
     if (($env{'form.domain'}) && 
 	(&Apache::lonnet::domain($env{'form.domain'},'description'))) {
 	$domain=$env{'form.domain'};
@@ -124,7 +137,6 @@ sub handler {
     my $role    = $r->dir_config('lonRole');
     my $loadlim = $r->dir_config('lonLoadLim');
     my $servadm = $r->dir_config('lonAdmEMail');
-    my $lonhost = $r->dir_config('lonHostID');
     my $tabdir  = $r->dir_config('lonTabDir');
     my $include = $r->dir_config('lonIncludes');
     my $expire  = $r->dir_config('lonExpire');
@@ -179,8 +191,18 @@ sub handler {
     if ($uextkey>2147483647) { $uextkey-=4294967296; }
 
 # -------------------------------------------------------- Store away log token
+    my $tokenextras;
+    if ($env{'form.role'}) {
+        $tokenextras = '&role='.&escape($env{'form.role'});
+    }
+    if ($env{'form.symb'}) {
+        if (!$tokenextras) {
+            $tokenextras = '&';
+        }
+        $tokenextras .= '&symb='.&escape($env{'form.symb'});
+    }
     my $logtoken=Apache::lonnet::reply(
-       'tmpput:'.$ukey.$lkey.'&'.$firsturl,
+       'tmpput:'.$ukey.$lkey.'&'.$firsturl.$tokenextras,
        $lonhost);
 
 # ------------------- If we cannot talk to ourselves, we are in serious trouble
@@ -283,7 +305,8 @@ sub handler {
     my $now=time;
     my $js = (<<ENDSCRIPT);
 
- <script language="JavaScript">
+ <script type="text/javascript">
+ // <![CDATA[
     function send()
     {
         this.document.server.elements.uname.value
@@ -327,6 +350,7 @@ sub handler {
         this.document.server.submit();
         return false;
     }
+ // ]]>
  </script>
 
 ENDSCRIPT
@@ -358,7 +382,7 @@ my %lt=&Apache::lonlocal::texthash(
                   'userload' => 'User Load',
                   'about'  => 'About LON-CAPA',
                   'access' => 'Accessibility Options',
-                  'catalog' => 'Course Catalog',
+                  'catalog' => 'Course/Community Catalog',
 		  'log' => 'Log in',
 		  'help' => 'Log-in Help',
 		  'serv' => 'Server',
@@ -386,7 +410,7 @@ my %lt=&Apache::lonlocal::texthash(
 
     if ($fullgraph) {
 	$r->print(
-		  '<table width="100%" cellpadding=0 cellspacing=0 border=0>');
+		  '<table width="100%" cellpadding="0" cellspacing="0" border="0">');
     }
 
     $r->print(<<ENDSERVERFORM);
@@ -426,8 +450,8 @@ ENDSERVERFORM
    <td width="100%" height=75 colspan=4 align="left" valign="top" bgcolor="$pgbg">
 HEADER
         if ($showbanner) {
-            $r->print(<<ENDBANNER); 
-<img src="$img" border=0 alt="The Learning Online Network with CAPA" />
+            $r->print(<<ENDBANNER);
+<img src="$img" border="0" alt="The Learning Online Network with CAPA" />
 ENDBANNER
         }
         $r->print(<<ENDSTART);
@@ -500,7 +524,7 @@ ENDTOP
                  .'<h2>'.&mt('Text-based Interface Login').'</h2>'
                  .$announcements);
     }
-    $r->print('<form name="client" onsubmit="return(send())">');
+    $r->print('<form name="client" action="" onsubmit="return(send())">');
     unless ($fullgraph) {
         $r->print(<<ENDACCESSOPTIONS);
 <h3>$lt{'options_headline'}</h3>
@@ -534,11 +558,11 @@ ENDNOOPT
                         .&mt('Use of LON-CAPA requires Javascript to be enabled in your web browser.')
                         .'</font></div></noscript></td>';
     $r->print(<<ENDLOGIN);
-     <input type="hidden" name="lextkey" value="$lextkey">
-     <input type="hidden" name="uextkey" value="$uextkey">
+     <input type="hidden" name="lextkey" value="$lextkey" />
+     <input type="hidden" name="uextkey" value="$uextkey" />
 
      <!-- Start the sub-table for text and input alignment -->
-     <table border=0 cellspacing=0 cellpadding=0>
+     <table border="0" cellspacing="0" cellpadding="0">
       <tr>$logintitle</tr>
       <tr>$noscript_warning</tr>
       <tr>
@@ -593,7 +617,7 @@ ENDLOGIN
    <!-- Row 5 Column 1 -->
    <td bgcolor="$sidebg" valign="middle" align="left">
      <br />
-     <table border=0 cellspacing=0 cellpadding=0>
+     <table border="0" cellspacing="0" cellpadding="0">
       <tr>
        <td bgcolor="$sidebg" align="left" valign="top">
         <small><b>&nbsp;&nbsp;&nbsp;$lt{'dom'}:&nbsp;</b></small>
@@ -659,8 +683,10 @@ $domainlogo
  </table>
 
 <script type="text/javascript">
+// <![CDATA[
 // the if prevents the script error if the browser can not handle this
 if ( document.client.uname ) { document.client.uname.focus(); }
+// ]]>
 </script>
 $helpdeskscript
 
@@ -671,6 +697,62 @@ ENDDOCUMENT
     return OK;
 }
 
+sub check_loginvia {
+    my ($domain,$lonhost) = @_;
+    if ($domain eq '' || $lonhost eq '') {
+        return;
+    }
+    my %domconfhash = &Apache::loncommon::get_domainconf($domain);
+    my $loginvia = $domconfhash{$domain.'.login.loginvia_'.$lonhost};
+    my $loginvia_exempt = $domconfhash{$domain.'.login.loginvia_exempt_'.$lonhost};
+    my $output;
+    if ($loginvia ne '') {
+        my $noredirect;
+        my $ip = $ENV{'REMOTE_ADDR'};
+        if ($ip eq '127.0.0.1') {
+            $noredirect = 1;
+        } else {
+            if ($loginvia_exempt ne '') {
+                my @exempt = split(',',$loginvia_exempt);
+                if (grep(/^\Q$ip\E$/,@exempt)) {
+                    $noredirect = 1;
+                }
+            }
+        }
+        unless ($noredirect) {
+            my ($newhost,$path);
+            if ($loginvia =~ /:/) {
+                ($newhost,$path) = split(':',$loginvia);
+            } else {
+                $newhost = $loginvia;
+            }
+            if ($newhost ne $lonhost) {
+                if (&Apache::lonnet::hostname($newhost) ne '') {
+                    $output = &redirect_page($newhost,$path);
+                }
+            }
+        }
+    }
+    return $output;
+}
+
+sub redirect_page {
+    my ($desthost,$path) = @_;
+    my $protocol = $Apache::lonnet::protocol{$desthost};
+    $protocol = 'http' if ($protocol ne 'https');
+    unless ($path =~ m{^/}) {
+        $path = '/'.$path;
+    }
+    my $url = $protocol.'://'.&Apache::lonnet::hostname($desthost).$path;
+    if ($env{'form.firsturl'} ne '') {
+        $url .='?firsturl='.$env{'form.firsturl'};
+    }
+    my $start_page = &Apache::loncommon::start_page('Switching Server ...',undef,
+                                                    {'redirect' => [0,$url],});
+    my $end_page   = &Apache::loncommon::end_page();
+    return $start_page.$end_page;
+}
+
 sub contactdisplay {
     my ($lt,$servadm,$showadminmail,$version,$authdomain,$helpdeskscript) = @_;
     my $contactblock;
@@ -688,6 +770,7 @@ sub contactdisplay {
         my $thisurl = &escape('/adm/login');
         $$helpdeskscript = <<"ENDSCRIPT";
 <script type="text/javascript">
+// <![CDATA[
 function helpdesk() {
     var codedom = document.client.udom.value;
     if (codedom == '') {
@@ -697,6 +780,7 @@ function helpdesk() {
     document.location.href = "/adm/helpdesk?"+querystr;
     return;
 }
+// ]]>
 </script>
 ENDSCRIPT
     }
@@ -729,7 +813,7 @@ sub coursecatalog_link {
     return <<"END";
      <tr>
       <td>&nbsp;</td>
-      <td><a href="/adm/coursecatalog"><b>$linkname</b></a></td>
+      <td><span class="LC_nobreak"><a href="/adm/coursecatalog"><b>$linkname</b></a></span></td>
      </tr>
 END
 }
