@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Switch Servers Handler
 #
-# $Id: switchserver.pm,v 1.21 2007/11/15 01:17:16 albertel Exp $
+# $Id: switchserver.pm,v 1.22 2009/04/14 23:52:07 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -73,7 +73,7 @@ sub handler {
     if (!defined($handle)) { return FORBIDDEN; }
 
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
-					    ['otherserver','role']);
+				['otherserver','role','origurl','symb']);
 
     my $switch_to=&Apache::lonnet::hostname($env{'form.otherserver'});
     if (! $env{'form.otherserver'}) {
@@ -132,6 +132,12 @@ sub handler {
 	      'username' => $env{'user.name'},
 	      'role'     => $env{'form.role'},
 	      'server'   => $r->dir_config('lonHostID'));
+    if ($env{'form.origurl'}) {
+        $info{'origurl'} = $env{'form.origurl'};
+    }
+    if ($env{'form.symb'}) {
+        $info{'symb'} = $env{'form.symb'};
+    }
     if ($env{'request.sso.login'}) {
 	$info{'sso.login'} = $env{'request.sso.login'};
     }
