@@ -1,5 +1,5 @@
 #
-# $Id: batchcreatecourse.pm,v 1.35 2010/01/30 22:16:50 bisitz Exp $
+# $Id: batchcreatecourse.pm,v 1.36 2010/05/24 06:32:38 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -434,7 +434,11 @@ sub build_course {
     }
     my $firstres =  $details->{'firstres'};
     if ($firstres eq '') {
-        $firstres = 'syl';
+        if ($crstype eq 'Community') {
+            $firstres = 'nav';
+        } else {
+            $firstres = 'syl';
+        }
     }
     foreach my $secid (sort(keys(%{$details->{'sections'}}))) {
         $sectionstr .= $details->{'sections'}{$secid}{'inst'}.':'.$details->{'sections'}{$secid}{'loncapa'}.',';
