@@ -1,6 +1,6 @@
 # functions to glue school database system into Lon-CAPA for 
 # automated enrollment
-# $Id: localenroll.pm,v 1.39 2009/09/13 03:14:12 raeburn Exp $
+# $Id: localenroll.pm,v 1.40 2010/07/12 23:55:07 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -346,7 +346,7 @@ A valid courserequest is confirmed by returning 'process'.
 The following can be returned: process, rejected, pending, approval or error (with error condition - no :), followed by a : and then an optional message. 
 
 (a) process  - the requestor is the recorded instructor - create the course
-(b) reject - the requestor should never be requesting this course, reject the
+(b) rejected - the requestor should never be requesting this course, reject the
     request permanently
 (c) pending - the requestor is not the recorded instructor, but could
     become so after administrative action at the institution. Put the
@@ -521,14 +521,18 @@ sub instcode_format () {
 
 Gather acceptable values for institutional categories to use in course creation request form for official courses.
 
- requires four arguments:
+ requires five arguments:
+
  domain ($dom)
  reference to array of titles ($codetitles)
  reference to hash of abbreviations used in categories ($cat_titles).
- reference to hash of arrays specifying sort order used in category titles ($cat_order).
+ reference to hash of arrays specifying sort order used in 
+           category titles ($cat_order).
+ reference to array which will contain order of component parts used 
+           in institutional code ($code_order).
 
  e.g., 
- @{$codetitles} = ("Year","Semester","Department","Number");
+ @{$codetitles} = ('Year','Semester',"Department','Number');
 
  %{$$cat_titles{'Semester'}} = (
                    fs => 'Fall',
@@ -536,23 +540,22 @@ Gather acceptable values for institutional categories to use in course creation
                    us => 'Summer');
 
  @{$$cat_order{'Semester'}} = ('ss','us','fs');
+ @{$code_order} = ('Semester','Year','Department','Number');
 
  returns 1 parameter: 'ok' if no processing errors.
 
 =cut
 
 sub possible_instcodes {
-    my ($dom,$codetitles,$cat_titles,$cat_order) = @_;
+    my ($dom,$codetitles,$cat_titles,$cat_order,$code_order) = @_;
     @{$codetitles} = ();
     %{$$cat_titles{'Semester'}} = ();
     @{$$cat_order{'Semester'}} = ('ss','us','fs');
-    ($$cat_titles{'Department'},$$cat_order{'Department'}) = &get_all_depts($dom);
-    ($$cat_titles{'Year'},$$cat_order{'Year'}) = &get_possible_years($dom);
+    @{$code_order} = ();
     return 'ok';
 }
 
 
-
 =pod
 
 =item institutional_photos()
