@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.248.2.5 2008/12/18 15:56:23 raeburn Exp $
+# $Id: inputtags.pm,v 1.259 2009/07/08 10:53:08 onken Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -25,6 +25,30 @@
 #
 # http://www.lon-capa.org/
 
+=pod
+
+=head1 NAME
+
+Apache::inputtags
+
+=head1 SYNOPSIS
+
+
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=head1 NOTABLE SUBROUTINES
+
+=over
+
+=item 
+
+=back
+
+=cut
+
 package Apache::inputtags;
 use HTML::Entities();
 use strict;
@@ -38,41 +62,47 @@ BEGIN {
     &Apache::lonxml::register('Apache::inputtags',('hiddenline','textfield','textline'));
 }
 
-#   Initializes a set of global variables used during the parse of the problem.
-#
-#  @Apache::inputtags::input        - List of current input ids.
-#  @Apache::inputtags::inputlist    - List of all input ids seen this problem.
-#  @Apache::inputtags::response     - List of all current resopnse ids.
-#  @Apache::inputtags::responselist - List of all response ids seen this 
-#                                       problem.
-#  @Apache::inputtags::hint         - List of all hint ids.
-#  @Apache::inputtags::hintlist     - List of all hint ids seen this problem.
-#  @Apache::inputtags::previous     - List describing if specific responseds
-#                                       have been used
-#  @Apache::inputtags::previous_version - Submission responses were used in.
-#  $Apache::inputtags::part         - Current part id (valid only in 
-#                                       <problem>)
-#                                     0 if not in a part.
-#  @Apache::inputtags::partlist     - List of part ids seen in the current
-#                                       <problem>
-#  @Apache::inputtags::status       - List of problem  statuses. First 
-#                                     element is the status of the <problem>
-#                                     the remainder are for individual <part>s.
-#  %Apache::inputtags::params       - Hash of defined parameters for the
-#                                     current response.
-#  @Apache::inputtags::import       - List of all ids for <import> thes get
-#                                     join()ed and prepended.
-#  @Apache::inputtags::importlist   - List of all import ids seen.
-#  $Apache::inputtags::response_with_no_part
-#                                   - Flag set true if we have seen a response
-#                                     that is not inside a <part>
-#  %Apache::inputtags::answertxt    - <*response> tags store correct
-#                                     answer strings for display by <textline/>
-#                                     in this hash.
-#  %Apache::inputtags::submission_display
-#                                   - <*response> tags store improved display
-#                                     of submission strings for display by part
-#                                     end.
+=pod
+
+=item initialize_inputtags()
+
+Initializes a set of global variables used during the parse of the problem.
+
+@Apache::inputtags::input        - List of current input ids.
+@Apache::inputtags::inputlist    - List of all input ids seen this problem.
+@Apache::inputtags::response     - List of all current resopnse ids.
+@Apache::inputtags::responselist - List of all response ids seen this 
+                                     problem.
+@Apache::inputtags::hint         - List of all hint ids.
+@Apache::inputtags::hintlist     - List of all hint ids seen this problem.
+@Apache::inputtags::previous     - List describing if specific responseds
+                                     have been used
+@Apache::inputtags::previous_version - Submission responses were used in.
+$Apache::inputtags::part         - Current part id (valid only in 
+                                     <problem>)
+                                   0 if not in a part.
+@Apache::inputtags::partlist     - List of part ids seen in the current
+                                     <problem>
+@Apache::inputtags::status       - List of problem  statuses. First 
+                                   element is the status of the <problem>
+                                   the remainder are for individual <part>s.
+%Apache::inputtags::params       - Hash of defined parameters for the
+                                   current response.
+@Apache::inputtags::import       - List of all ids for <import> thes get
+                                   join()ed and prepended.
+@Apache::inputtags::importlist   - List of all import ids seen.
+$Apache::inputtags::response_with_no_part
+                                 - Flag set true if we have seen a response
+                                   that is not inside a <part>
+%Apache::inputtags::answertxt    - <*response> tags store correct
+                                   answer strings for display by <textline/>
+                                   in this hash.
+%Apache::inputtags::submission_display
+                                 - <*response> tags store improved display
+                                   of submission strings for display by part
+                                   end.
+
+=cut
 
 sub initialize_inputtags {
     @Apache::inputtags::input=();
@@ -358,12 +388,13 @@ sub start_textline {
 	     && $Apache::lonhomework::type ne 'exam') {
 	my $size = &Apache::lonxml::get_param('size',$parstack,$safeeval);
 	if ($size != 0) {$size=$size*2; $size.=' mm';} else {$size='40 mm';}
-	if ($env{'form.pdfFormFields'} eq 'yes') {
+	if ($env{'form.pdfFormFields'} eq 'yes'
+            && $Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
             my $fieldname = $env{'request.symb'}.
                                  '&part_'. $Apache::inputtags::part.
                                  '&textresponse'.
                                  '&HWVAL_' . $Apache::inputtags::response['-1'];
-            $result="\n\\\\\n".'\textField{'.$fieldname.'}{'.$size.'}{12 bp}';
+            $result='\textField{'.$fieldname.'}{'.$size.'}{12 bp}';
         } else {
             $result='\framebox['.$size.'][s]{\tiny\strut}';
         }
@@ -424,15 +455,22 @@ sub end_hiddenline {
     return "";
 }
 
-# $part -> partid
-# $id -> responseid
-# $uploadefiletypes -> comma seperated list of extensions allowed or * for any
-# $which -> 'uploadonly'  -> only newly uploaded files
-#           'portfolioonly' -> only allow files from portfolio
-#           'both' -> allow files from either location
-# $extratext -> additional text to go between the link and the input box
-# $maxfilesize -> maximum cumulative filesize for submitted files (in MB).
-# returns a table row <tr> 
+=pod
+
+=item file_selector()
+
+$part -> partid
+$id -> responseid
+$uploadefiletypes -> comma seperated list of extensions allowed or * for any
+$which -> 'uploadonly'  -> only newly uploaded files
+          'portfolioonly' -> only allow files from portfolio
+          'both' -> allow files from either location
+$extratext -> additional text to go between the link and the input box
+$maxfilesize -> maximum cumulative filesize for submitted files (in MB).
+returns a table row <tr> 
+
+=cut
+
 sub file_selector {
     my ($part,$id,$uploadedfiletypes,$which,$extratext,$maxfilesize)=@_;
     if (!$uploadedfiletypes) { return ''; }
@@ -445,8 +483,8 @@ sub file_selector {
     $result.='<tr><td>';
     if (($uploadedfiletypes ne '*') || ($maxfilesize)) {
         if ($uploadedfiletypes ne '*') {
-            $result.=
-                &mt('Allowed filetypes: [_1]','<b>'.$uploadedfiletypes.'</b>').'<br />';
+	    $result.=
+	        &mt('Allowed filetypes: [_1]','<b>'.$uploadedfiletypes.'</b>').'<br />';
         }
         if ($maxfilesize) {
             $result.=&mt('Combined size of files not to exceed: [_1] MB[_2].',
@@ -486,7 +524,7 @@ sub show_past_file_submission {
     my $icon=&Apache::loncommon::icon($url);
     my $curfile='<a href="'.$url.'"><img src="'.$icon.
 	'" border="0" />'.$uploadedfile.'</a>';
-    return &mt('Currently submitted: <tt>[_1]</tt>',$curfile);
+    return &mt('Currently submitted: [_1]','<tt>'.$curfile.'</tt>');
 
 }
 
@@ -516,7 +554,9 @@ sub show_past_portfile_submission {
 	my $bad_files = '<span class="LC_filename">'.
 	    join('</span>, <span class="LC_filename">',@bad_file_list).
 	    '</span>';
-	$result.='<br />'.&mt('<span class="LC_error">These file(s) don\'t exist:</span> [_1]',$bad_files);
+	$result.='<p><span class="LC_error">'
+                .&mt("These file(s) don't exist: [_1]",$bad_files)
+                .'</span></p>';
     }
     return $result;
 
@@ -642,6 +682,7 @@ sub finalizeawards {
 
 sub decideoutput {
     my ($award,$awarded,$awardmsg,$solved,$previous,$target)=@_;
+
     my $message='';
     my $button=0;
     my $previousmsg;
@@ -695,7 +736,7 @@ sub decideoutput {
 			      '.disable_receipt_display'} ne 'yes') &&
                     ($Apache::lonhomework::type ne 'practice')) { 
 		    $message.=(($target eq 'web')?'<br />':' ').
-			&mt('Your receipt is [_1]',
+			&mt('Your receipt no. is [_1]',
 			    (&Apache::lonnet::receipt($Apache::inputtags::part).
 			     (($target eq 'web')?&Apache::loncommon::help_open_topic('Receipt'):'')));
 		}
@@ -777,13 +818,13 @@ sub decideoutput {
         $css_class=$possible_class{'not_charged_try'};
         $button=1;
     } elsif ($award eq 'INVALID_FILETYPE') {
-	$message = &mt('Submission won\'t be graded. The type of file submitted is not allowed.');
+	$message = &mt("Submission won't be graded. The type of file submitted is not allowed.");
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'SIG_FAIL') {
 	my ($used,$min,$max)=split(':',$awardmsg);
 	my $word = ($used < $min) ? 'more' : 'fewer';
-	$message = &mt("Submission not graded.  Use $word digits.",$used);
+	$message = &mt("Submission not graded. Use $word digits.",$used);
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'UNIT_INVALID_INSTRUCTOR') {
@@ -832,7 +873,7 @@ sub decideoutput {
 	$css_class=$possible_class{'no_grade'};
 	$button=1;
     } elsif ($award eq 'DRAFT') {
-	$message = &mt("A draft copy has been saved.");
+	$message = &mt("Copy saved but not submitted.");
 	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'ASSIGNED_SCORE') {
@@ -1372,4 +1413,10 @@ sub previous_tries {
 
 1;
 __END__
+
+=pod
+
+=back
+
+=cut
  
