@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # external style responses
 #
-# $Id: loncapagrade.pm,v 1.4 2007/09/11 19:07:01 albertel Exp $
+# $Id: loncapagrade.pm,v 1.6 2008/11/20 15:19:15 jms Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,9 @@
 # http://www.lon-capa.org/
 #
 # 1/26 Guy
+
+
+
 package Apache::loncapagrade;
 use strict;
 
@@ -96,3 +99,42 @@ sub end_message {
 1;
 __END__
 
+=pod
+
+=head1 NAME
+
+Apache::loncapagrade
+
+=head1 SYNOPSIS
+
+Handler to evaluate externally graded responses.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 SUBROUTINES
+
+=over
+
+=item start_loncapagrade()
+
+=item end_loncapagrade()
+
+=item start_awarddetail()
+
+=item end_awarddetail()
+
+=item start_message()
+
+=item end_message()
+
+=back
+
+=head2 notes
+
+results of parse end up in here:
+undef(%Apache::loncapagrade::results);
+
+=cut
+
+
