@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.310 2009/05/11 16:51:22 bisitz Exp $
+# $Id: lonhomework.pm,v 1.310.4.1 2010/08/20 03:48:29 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -111,7 +111,11 @@ sub get_target {
 	} elsif ( $env{'form.grade_target'} eq 'webgrade'
 		  && ($Apache::lonhomework::queuegrade eq 'F' )) {
 	    return ($env{'form.grade_target'});
-	}
+        } elsif ($env{'form.grade_target'} eq 'answer') {
+            if ($env{'form.answer_output_mode'} eq 'tex') {
+                return ($env{'form.grade_target'});
+            }
+        }
 	if ($env{'form.webgrade'} &&
 	    ($Apache::lonhomework::modifygrades eq 'F'
 	     || $Apache::lonhomework::queuegrade eq 'F' )) {
