@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Full matching style response
 #
-# $Id: matchresponse.pm,v 1.73.2.1 2008/12/11 01:20:32 raeburn Exp $
+# $Id: matchresponse.pm,v 1.78 2009/12/09 11:30:45 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -180,7 +180,7 @@ sub end_itemgroup {
 	    $i++;
 	}
 	$table.=' \end{description}  \strut ';
-	if ($Apache::lonhomework::type eq 'exam') {$table.='\vskip -13 mm \strut ';}
+	if ($Apache::lonhomework::type eq 'exam')  {$table.='\vskip -13 mm \strut ';}
 	$Apache::matchresponse::itemtable{'display'}=$table;
 	$Apache::lonxml::post_evaluate=0;
     }
@@ -513,7 +513,14 @@ sub displayfoils {
 		$optionlist="<option></option>\n";
 	    } else {
 		if ($Apache::lonhomework::type ne 'exam') {
-                    $optionlist='\framebox[10 mm][s]{\tiny\strut}';
+                    if($env{'form.pdfFormFields'} eq 'yes'
+                       && $Apache::inputtags::status['-1'] eq 'CAN_ANSWER') {
+                        my $fieldname = $env{'request.symb'} . '&part_'. $Apache::inputtags::part .'&matchresponse'. '&HWVAL_' . $Apache::inputtags::response['-1'] . ':' . $temp . '&submit_' . $Apache::inputtags::part . '&';
+                        $optionlist = &Apache::lonxml::print_pdf_start_combobox($fieldname);
+                    } else {
+
+                        $optionlist='\framebox[10 mm][s]{\tiny\strut}';
+                    }
                 }
 	    }
 	    my $option;
@@ -521,10 +528,16 @@ sub displayfoils {
 		if ($option eq $last_letter) {
 		    if ($target ne 'tex') {
                         $optionlist.="<option selected=\"on\">$option</option>\n";
+                    } elsif ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
+                             && $Apache::inputtags::status['-1'] eq 'CAN_ANSWER') {
+                        $optionlist .= &Apache::lonxml::print_pdf_add_combobox_option($option);
                     }
 		} else {
 		    if ($target ne 'tex') {
                         $optionlist.="<option>$option</option>\n";
+                    } elsif ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
+                             && $Apache::inputtags::status['-1'] eq 'CAN_ANSWER') {
+                        $optionlist .= &Apache::lonxml::print_pdf_add_combobox_option($option);
                     }
 		}
 	    }
@@ -568,22 +581,27 @@ sub displayfoils {
 		# Note that if left or right positioned, we must
 		# confine the bubbles to righttabsize:
 		#
-		if ($Apache::lonhomework::type eq 'exam') {
+		if ($Apache::lonhomework::type eq 'exam' && $env{'form.pdfFormFields'} ne 'yes') {
 		    $question.=' '.$optionlist.$text."\n";
 		    my @emptyItems = ();
 		    for (my $i=0;$i<=$#used_letters;$i++) {push @emptyItems, ' ';}
 		    $question.='\vskip -1 mm\noindent\begin{list}{}{\setlength{\listparindent}{0mm}\setlength{\leftmargin}{2mm}}'
 			.'\item \hskip -3mm \textbf{'.$internal_counter.'}';
 		    if (&itemdisplay('left') || &itemdisplay('right')) {
-			$question .= &Apache::optionresponse::bubbles(\@used_letters,\@emptyItems, "", $righttabsize);
+			$question .= '\vskip -4 mm' . &Apache::optionresponse::bubbles(\@used_letters,\@emptyItems, "", $righttabsize);
 		    }
 		    else {
-			$question .= &Apache::optionresponse::bubbles(\@used_letters,\@emptyItems);
+			$question .= '\vskip -4 mm' . &Apache::optionresponse::bubbles(\@used_letters,\@emptyItems);
 		    }
 		    $question .= '\end{list} \vskip -8 mm \strut ';
 		    $internal_counter++;
 	        } else {
-                    $question.=' '.$optionlist.$text.'\strut\\\\\strut '."\n";
+                    if($env{'form.pdfFormFields'} eq 'yes' 
+                            && $Apache::inputtags::status['-1'] eq 'CAN_ANSWER') {
+                        $question .= " $optionlist ". &Apache::lonxml::print_pdf_end_combobox($text).'\strut';
+                    } else {
+                        $question.=' '.$optionlist.$text.'\strut\\\\\strut '."\n";
+                    }
 		}
             } 
 	    $temp++;
@@ -741,11 +759,13 @@ sub end_foil {
 						     $safeeval);
 	    if ( $Apache::matchresponse::conceptgroup
 		 && !&Apache::response::showallfoils() ) {
+
 		push @{ $Apache::response::conceptgroup{'names'} }, $name;
 		$Apache::response::conceptgroup{"$name.value"} = $value;
 		$Apache::response::conceptgroup{"$name.text"} = $text;
 		$Apache::response::conceptgroup{"$name.location"} = $location;
 	    } else {
+
 		push @{ $Apache::response::foilgroup{'names'} }, $name;
 		$Apache::response::foilgroup{"$name.value"} = $value;
 		$Apache::response::foilgroup{"$name.text"} = $text;
