@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.151.2.1 2008/12/11 01:59:01 raeburn Exp $
+# $Id: optionresponse.pm,v 1.162 2010/02/05 23:02:39 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -25,6 +25,11 @@
 #
 # http://www.lon-capa.org/
 #
+
+
+
+
+
 package Apache::optionresponse;
 use strict;
 use Apache::response();
@@ -118,10 +123,21 @@ sub start_foilgroup {
         </td>
         <td>Delete an Option:
 	  <select name="$Apache::lonxml::curdepth.deleteopt">$optionlist</select>
+        </td>
 ENDTABLE
-    $result.= &Apache::edit::checked_arg('Print options:','texoptions',
+    $result.= '<td>'.&Apache::edit::checked_arg('Print options:','texoptions',
 					 [ ['nochoice','Don\'t show option list'] ]
-					 ,$token);
+					 ,$token).'</td>';
+    $result.= '<td><label>'.&mt('Two-option checkboxes for:').
+              '<select name="checkboxvalue_'.$Apache::lonxml::curdepth.'">';
+    foreach $option (('',@opt)) {
+       $result.='<option value="'.$option.'"';
+       if ($option eq &Apache::lonxml::get_param('checkboxvalue',$parstack,$safeeval)) {
+          $result.=' selected="selected"';
+       }
+       $result.='>'.$option.'</option>';
+    }
+    $result.='</select></label>';  
     $result.= &Apache::edit::end_row();
     $result.= &Apache::edit::start_spanning_row();
     $result.= $insertlist.'<br />';
@@ -146,7 +162,7 @@ ENDTABLE
       $optchanged=1;
     }
     my $rebuildtag = &Apache::edit::get_new_args($token,$parstack,$safeeval,
-						 ('texoptions'));
+						 'texoptions','checkboxvalue');
     if ($optchanged || $rebuildtag ) {
       $result = "<foilgroup options=\"(";
       foreach my $option (@options) {
@@ -157,12 +173,17 @@ ENDTABLE
       chop $result;
       $result.=')" ';
       $result .= 'texoptions="'.$token->[2]{'texoptions'}.'" ';
+      $result .= 'checkboxvalue="'.$token->[2]{'checkboxvalue'}.'"';
       $result .= '>';
     } # else nothing changed so just use the default mechanism
   }
   if ($target eq 'tex' and $Apache::lonhomework::type ne 'exam') {
+    if($env{'form.pdfFormFields'} ne 'yes') {
       $result .= ' \renewcommand{\labelenumi}{\Alph{enumi}.}
                    \begin{enumerate} ';
+    } else {
+      $result .= "\\\\";
+    }
   }
   return $result;
 }
@@ -181,13 +202,14 @@ sub end_foilgroup {
 
     my $TeXlayout=&Apache::lonxml::get_param('TeXlayout',$parstack,$safeeval,
 					     -2,0);
+    my $checkboxvalue=&Apache::lonxml::get_param('checkboxvalue',$parstack,$safeeval);
     if ($target eq 'tex' && $tex_option_switch eq 'nochoice') {@opt=();}
     &Apache::lonxml::debug("Options are $#opt");
     my $max = &Apache::lonxml::get_param('max',$parstack,$safeeval,'-2');
     my $randomize = &Apache::lonxml::get_param('randomize',$parstack,
 					       $safeeval,'-2');
     if ($target eq 'web' || $target eq 'tex') {
-      $result.=&displayfoils($target,$max,$randomize,$TeXlayout,@opt);
+      $result.=&displayfoils($target,$max,$randomize,$TeXlayout,$checkboxvalue,@opt);
       $Apache::lonxml::post_evaluate=0;
     } elsif ( $target eq 'answer') {
       $result.=&displayanswers($max,$randomize,@opt);
@@ -292,7 +314,11 @@ sub end_foilgroup {
     $result.=&Apache::edit::end_table();
   }
   if ($target eq 'tex' and $Apache::lonhomework::type ne 'exam') {
+    if($env{'form.pdfFormFields'} ne 'yes') {
       $result .= '\end{enumerate}';
+    } else {
+      $result .= "\\\\";
+    }
   }
   &Apache::response::poprandomnumber();
   return $result;
@@ -346,6 +372,15 @@ sub displayanswers {
     return $result;
 }
 
+sub check_box_opt {
+    my ($target,$checkboxvalue,@opt)=@_;
+# Check if we are in checkbox mode: checkboxvalue specified, on web, only two options.
+# If so, return "checked" value
+    if ($#opt!=1) { return ''; }
+    if ($target ne 'web') { return ''; }
+    return $checkboxvalue;
+}
+
 sub check_for_invalid {
     my ($names,$options) = @_;
     my %bad_names;
@@ -368,7 +403,7 @@ sub check_for_invalid {
 }
 
 sub displayfoils {
-  my ($target,$max,$randomize,$TeXlayout,@opt)=@_;
+  my ($target,$max,$randomize,$TeXlayout,$checkboxvalue,@opt)=@_;
   if (!defined(@{ $Apache::response::foilgroup{'names'} })) {return;}
   my @names = @{ $Apache::response::foilgroup{'names'} };
   my @truelist;
@@ -414,6 +449,11 @@ sub displayfoils {
     my $temp=1;
     my %lastresponse=&Apache::lonnet::str2hash($Apache::lonhomework::history{"resource.$part.$id.submission"});
     my $internal_counter=$Apache::lonxml::counter;
+    my $checkboxopt=&check_box_opt($target,$checkboxvalue,@opt);
+    if ($checkboxopt) {
+       $result.='<br />'.&mt('Choices: ').'<b>'.$opt[0].','.$opt[1].'</b>. '.
+                &mt('Select all that are <b>[_1]</b>.',$checkboxopt);
+    }
     foreach $name (@whichopt) {
       my $text=$Apache::response::foilgroup{$name.'.text'};
       if ($text!~/^\s*$/) {
@@ -425,20 +465,61 @@ sub displayfoils {
       }
       my $lastopt=$lastresponse{$name};
       my $optionlist="<option></option>\n";
+
+      if($target eq 'tex' and $env{'form.pdfFormFields'} eq 'yes'
+         && $Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+          my $fieldname = $env{'request.symb'}.'&part_'.$Apache::inputtags::part.'&optionresponse'.'&HWVAL_'.$Apache::inputtags::response['-1'].':'.$temp;
+          $optionlist =  &Apache::lonxml::print_pdf_start_combobox($fieldname);
+      }
+
       foreach my $option (@opt) {
 	  my $escopt=&HTML::Entities::encode($option,'\'"&<>');
-	  if ($option eq $lastopt) {
-	      $optionlist.="<option value='".$escopt."' selected=\"selected\">$option</option>\n";
-	  } else {
-	      $optionlist.="<option value='".$escopt."'>$option</option>\n";
-	  }
+          if ($option eq $lastopt) {
+              if ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
+                  && $Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+                  $optionlist .= &Apache::lonxml::print_pdf_add_combobox_option($option);
+              } else {
+                  $optionlist.="<option value='".$escopt."' selected=\"selected\">$option</option>\n";
+              }
+          } else {
+              if ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
+                  && $Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+                  $optionlist .= &Apache::lonxml::print_pdf_add_combobox_option($option);
+              } else {
+                  $optionlist.="<option value='".$escopt."'>$option</option>\n";
+              }
+          }
       }
       if ($target ne 'tex') {
 	  if ($Apache::lonhomework::type ne 'exam') {
-	      $optionlist='<select onchange="javascript:setSubmittedPart(\''.
+# we are on the web, this is not an exam, and the problem can be answered
+              if ($checkboxopt) {
+# generate checkboxes
+                  my $fieldname=$Apache::inputtags::response['-1'].':'.$temp;
+                  my $altopt=$opt[0];
+                  if ($opt[0] eq $checkboxopt) {
+                     $altopt=$opt[1];
+                  }
+                  my $defopt=$lastopt;
+                  unless ($defopt) { $defopt=$altopt; }
+                  my $escdefopt=&HTML::Entities::encode($defopt,'\'"&<>');
+                  my $esccheckboxopt=&HTML::Entities::encode($checkboxopt,'\'"&<>');
+                  my $escaltopt=&HTML::Entities::encode($altopt,'\'"&<>');
+# checkboxopt is how the box is labelled
+# altopt is the alternative option
+# lastopt is what the user submitted before
+# defopt is what the field is going to start out with: either previous choice or altopt
+# fieldname is this input field's name after HWVAL_
+                  $optionlist='<input type="hidden" name="HWVAL_'.$fieldname.'" value="'.$escdefopt.'" />'.
+                  '<input type="checkbox" name="HWCHK_'.$fieldname.'" onclick="javascript:if (this.form.elements[\'HWCHK_'.
+                  $fieldname.'\'].checked) { this.form.elements[\'HWVAL_'.$fieldname.'\'].value=\''.$esccheckboxopt.'\'; } else { this.form.elements[\'HWVAL_'.$fieldname.'\'].value=\''.$escaltopt.'\'; };setSubmittedPart(\''.$part.'\');"'.($defopt eq $checkboxopt?' checked="checked"':'')." />\n";
+              } else {
+# classic selection list
+	          $optionlist='<select onchange="javascript:setSubmittedPart(\''.
 		  $part.'\');" name="HWVAL_'.
 		  $Apache::inputtags::response['-1'].':'.$temp.'">'.
 		  $optionlist."</select>\n";
+              }
 	  } else {
 	      $optionlist='<u>'.('&nbsp;'x10).'</u>';
 	  }
@@ -469,13 +550,18 @@ sub displayfoils {
 	  if ($text=~m/\\item /) {
 	      if ($Apache::lonhomework::type eq 'exam') {
 	          $text=~s/\\item/\\vskip 2 mm/;
-	      }
-	      $result.= $texoptionlist.$text;
-	  } else {
+	      } elsif ($env{'form.pdfFormFields'} ne 'yes') {
+                  $result.= $texoptionlist.$text;
+              }
+          } else {
 	      if ($Apache::lonhomework::type eq 'exam') {
 		  $result.= $texoptionlist.'  '.$text;
-	      } else {
-		  if ($text=~/\S/) {$result.= $texoptionlist.'\vspace*{-2 mm}\item '.$text;} else {$result.= $texoptionlist;}
+	      } elsif ($env{'form.pdfFormFields'} ne 'yes') {
+		  if ($text=~/\S/) {
+                      $result.= $texoptionlist.'\vspace*{-2 mm}\item '.$text;
+                  } else {
+                      $result.= $texoptionlist;
+                  }
 	      }
 	  }
 	  if ($Apache::lonhomework::type eq 'exam') {
@@ -484,6 +570,12 @@ sub displayfoils {
 		  '\end{enumerate} \vskip -8 mm \strut ';
 	      $internal_counter++;
 	  }
+          if ($target eq 'tex' && $env{'form.pdfFormFields'} eq 'yes'
+              && $Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+              $text =~ s/\\item//m;
+              $result .= " $optionlist ". &Apache::lonxml::print_pdf_end_combobox($text).'\strut \\\\';
+              $temp++;
+          }
 	  $displayoptionintex=0;
       }
     }
@@ -743,3 +835,64 @@ sub insert_drawoptionlist {
 1;
 __END__
  
+=head1 NAME
+
+Apache::optionresponse.pm;
+
+=head1 SYNOPSIS
+
+Handles tags associated with showing a list of
+options.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 HANDLER SUBROUTINE
+
+start_optionresponse()
+
+=head1 OTHER SUBROUTINES
+
+=over
+
+=item end_optionresponse()
+
+=item start_foilgroup()
+
+=item end_foilgroup()
+
+=item getfoilcounts()
+
+=item displayanswers()
+
+=item check_for_invalid()
+
+=item displayfoils()
+
+=item optionlist_correction()
+
+=item webbubbles()
+
+=item bubbles()
+
+=item start_conceptgroup()
+
+=item end_conceptgroup()
+
+=item insert_conceptgroup()
+
+=item start_foil()
+
+=item end_foil()
+
+=item start_drawoptionlist()
+
+=item end_drawoptionlist()
+
+=item insert_foil()
+
+=item insert_drawoptionlist()
+
+=back
+
+=cut
