@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for displaying the course catalog interface
 #
-# $Id: coursecatalog.pm,v 1.53.4.5 2010/04/14 18:58:37 raeburn Exp $
+# $Id: coursecatalog.pm,v 1.53.4.7 2010/10/07 14:45:04 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -194,7 +194,7 @@ sub course_details {
     my $brtexttwo = 'Course details';
     if ($env{'form.currcat_0'} eq 'communities::0') {
         $brtextone = 'Community listing';
-        $brtextone = 'Community details';
+        $brtexttwo = 'Community details';
     }
     &Apache::lonhtmlcommon::add_breadcrumb
              ({href=>"javascript:document.$formname.submit()",
@@ -402,7 +402,7 @@ sub category_breadcrumbs {
                     $catlinks .= '<option value="">'.&mt('De-select').'</option>';
                     for (my $j=0; $j<@{$cats[$shallower]{$container}}; $j++) {
                         my $name = $cats[$shallower]{$container}[$j];
-                        my $item = &escape($name).':'.$container.':'.$shallower;
+                        my $item = &escape($name).':'.&escape($container).':'.$shallower;
                         my $selected = '';
                         if ($item eq $env{'form.currcat_'.$shallower}) {
                             $selected = ' selected="selected"';
