@@ -3,7 +3,7 @@
 # institutional log-in ID (institutional authentication required - localauth
 #  or kerberos) or an e-mail address.
 #
-# $Id: createaccount.pm,v 1.37 2009/10/23 16:14:43 bisitz Exp $
+# $Id: createaccount.pm,v 1.37.6.1 2010/08/20 04:01:47 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -547,7 +547,7 @@ sub process_email_request {
                 if ($uhome eq 'no_host') {
                     my (%rulematch,%inst_results,%curr_rules,%got_rules,%alerts);
                     &call_rulecheck($useremail,$domain,\%alerts,\%rulematch,
-                                    \%inst_results,\%curr_rules,%got_rules,'username');
+                                    \%inst_results,\%curr_rules,\%got_rules,'username');
                     if (ref($alerts{'username'}) eq 'HASH') {
                         if (ref($alerts{'username'}{$domain}) eq 'HASH') {
                             if ($alerts{'username'}{$domain}{$useremail}) {
@@ -918,7 +918,7 @@ sub username_check {
     my (%rulematch,%inst_results,$checkfail,$rowcount,$editable,$output,$msg,
         %alerts,%curr_rules,%got_rules);
     &call_rulecheck($username,$domain,\%alerts,\%rulematch,
-                    \%inst_results,\%curr_rules,%got_rules,'username');
+                    \%inst_results,\%curr_rules,\%got_rules,'username');
     if (ref($alerts{'username'}) eq 'HASH') {
         if (ref($alerts{'username'}{$domain}) eq 'HASH') {
             if ($alerts{'username'}{$domain}{$username}) {
@@ -1065,7 +1065,7 @@ sub username_activation {
         # Call modifyuser
         my (%rulematch,%inst_results,%curr_rules,%got_rules,%alerts,%info);
         &call_rulecheck($username,$domain,\%alerts,\%rulematch,
-                        \%inst_results,\%curr_rules,%got_rules);
+                        \%inst_results,\%curr_rules,\%got_rules);
         my @userinfo = ('firstname','middlename','lastname','generation',
                         'permanentemail','id');
         my %canmodify = 
