@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Announce
 #
-# $Id: lonannounce.pm,v 1.74 2008/10/14 13:52:23 amueller Exp $
+# $Id: lonannounce.pm,v 1.82 2010/03/16 20:10:13 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -45,7 +45,7 @@ my %todayhash;
 my %showedcheck;
 
 sub editfield {
-    my ($r,$start,$end,$text)=@_;
+    my ($r,$start,$end,$text,$crstype)=@_;
     # Deal with date forms
     my $startdateform = &Apache::lonhtmlcommon::date_setter('anno',
                                                             'startdate',
@@ -61,6 +61,10 @@ sub editfield {
 				       'start' => 'Starting date',
 				       'end' => 'Ending date',
 				       'incrss' => 'Include in course RSS newsfeed');
+    if ($crstype eq 'Community') {
+        $lt{'annon'} = &mt('Community Announcements');
+        $lt{'incrss'} = &mt('Include in community RSS newsfeed');
+    }
 
     $r->print(<<ENDFORM);
 <h2>$lt{'annon'} $help</h2>
@@ -415,7 +419,8 @@ sub picklink {
 
 sub dialscript {
     return (<<ENDDIA);
-<script language="Javascript">
+<script type="text/javascript" language="JavaScript">
+// <![CDATA[
 function dialin(day,month,year) {
 	opener.document.$env{'form.formname'}.$env{'form.element'}\_year.value=year;
     var slct=opener.document.$env{'form.formname'}.$env{'form.element'}\_month;
@@ -427,6 +432,7 @@ function dialin(day,month,year) {
     opener.$env{'form.element'}\_checkday();
     self.close();
 }
+// ]]>
 </script>
 ENDDIA
 }
@@ -502,8 +508,8 @@ sub handler {
 
 # ---------------------------------------------- See if we are in pickdate mode
     my $pickdatemode=($env{'form.pickdate'} eq 'yes');
-    my $pickinfo='&pickdate=yes&formname='.$env{'form.formname'}.
-	'&element='.$env{'form.element'};
+    my $pickinfo='&amp;pickdate=yes&amp;formname='.$env{'form.formname'}.
+	'&amp;element='.$env{'form.element'};
 # --------------------------------------------- Find out first day of the month
 
     my $tk = &Apache::loncommon::maketime( 'day' => 1,
@@ -517,7 +523,8 @@ sub handler {
 
 # ------------------------------------------------------------ Print the screen
     my $js = <<ENDDOCUMENT;
-<script type="text/javascript">
+<script type="text/javascript" language="JavaScript">
+// <![CDATA[
 
     function trysubmit() {
         document.anno.action.value="new";
@@ -528,6 +535,7 @@ sub handler {
         document.anno.action.value="del";
 	document.anno.submit();
     }
+// ]]>
 </script>
 ENDDOCUMENT
 
@@ -538,8 +546,8 @@ ENDDOCUMENT
 		  &dialscript().
 		  '<font size="1">');
     } else {
-       $r->print(&Apache::loncommon::start_page("Announcements and Calendar",
-						$js));
+        my $brcrum = [{href=>"/adm/announcements",text=>"Announcements and Calendar"}];
+        $r->print(&Apache::loncommon::start_page("Communication",$js,{'bread_crumbs' => $brcrum}));
     }
 # does this user have privileges to post, etc?
     my $allowed=0;
@@ -590,11 +598,12 @@ ENDDOCUMENT
 	}
     }
     $r->print(
-  '<br /><input type="submit" name="serveraction" value="'.&mt('Post').'"></form><hr />');
+  '<br /><input type="submit" name="serveraction" value="'.&mt('Post').'" /></form><hr />');
     }
     if ($allowed) {
         my $coursenum=$env{'course.'.$env{'request.course.id'}.'.num'};
         my $coursedom=$env{'course.'.$env{'request.course.id'}.'.domain'};
+        my $crstype = &Apache::loncommon::course_type();
 # ----------------------------------------------------- Store new submitted one
         if ($env{'form.action'} eq 'new') {
 	    my $startdate = 
@@ -612,7 +621,13 @@ ENDDOCUMENT
 		$startdate.'_'.$enddate => 
 		    $env{'form.msg'} },$coursedom,$coursenum);
 	    if ($env{'form.rsspost'}) {
-               &Apache::lonrss::addentry($coursenum,$coursedom,'Course_Announcements',
+               my $feed;
+               if ($crstype eq 'Community') {
+                   $feed = 'Community_Announcements';
+               } else {
+                   $feed = 'Course_Announcements';
+               }
+               &Apache::lonrss::addentry($coursenum,$coursedom,$feed,
 					 &mt('Event from [_1] to [_2]',
 					     &Apache::lonlocal::locallocaltime($startdate),
 					     &Apache::lonlocal::locallocaltime($enddate)),
@@ -634,7 +649,7 @@ ENDDOCUMENT
         $tomorrowhash{'day'}++;
         my $tomorrow=&Apache::loncommon::maketime(%tomorrowhash);
         
-        &editfield($r,$today,$tomorrow,'');
+        &editfield($r,$today,$tomorrow,'',$crstype);
     }
 # ----------------------------------------------------- Summarize all calendars
     my %allcal=&get_all_calendars();
@@ -656,7 +671,7 @@ ENDDOCUMENT
                  .&mt('No calendar available for this date.')
                  .'</p>'
                  .'<a href="/adm/announcements?month='.$todayhash{'month'}
-                 .'&year='.$todayhash{'year'}.'">'.&mt('Current Month').'</a>'
+                 .'&amp;year='.$todayhash{'year'}.'">'.&mt('Current Month').'</a>'
 		 .&Apache::loncommon::end_page());
 	return OK;
     }
@@ -695,14 +710,14 @@ ENDDOCUMENT
     }
 
     $r->print(
- '<a href="/adm/announcements?month='.$pm.'&year='.$py.
+ '<a href="/adm/announcements?month='.$pm.'&amp;year='.$py.
  ($pickdatemode?$pickinfo:'').'">'.&mt('Previous Month').'</a> '.
- '<a href="/adm/announcements?month='.$fm.'&year='.$fy.
+ '<a href="/adm/announcements?month='.$fm.'&amp;year='.$fy.
  ($pickdatemode?$pickinfo:'').'">'.&mt('Next Month').'</a>'.
  '&nbsp;&nbsp;&nbsp;<a href="/adm/announcements?month='.$todayhash{'month'}.
- '&year='.$todayhash{'year'}.
- ($pickdatemode?$pickinfo:'').'">'.&mt('Current Month').'</a><p>'.
-        '<table class="'.$class.'" cols="7" rows="5"><tr>');
+ '&amp;year='.$todayhash{'year'}.
+ ($pickdatemode?$pickinfo:'').'">'.&mt('Current Month').'</a><div>'.
+        '<table class="'.$class.'"><tr>');
     for (my $i=0; $i<@localdays; $i++) {
         $r->print('<th>'.&mt($localdays[$i]).'</th>');
     }
@@ -742,22 +757,23 @@ ENDDOCUMENT
         }
     }
 # ------------------------------------------------------------------- End table
-    $r->print('</table>');
+    $r->print('</table></div>');
 # ----------------------------------------------------------------- Check marks
     undef(%showedcheck);
 # --------------------------------------------------------------- Remove button
     if ($allowed) { $r->print('<br /><input type="button" onClick="removesub()" value="'.&mt('Remove Checked Entries').'">'.
 			      &Apache::loncommon::help_open_topic('Calendar_Remove_Announcement').'</form>'); }
     $r->print('<p>'.
- '<a href="/adm/announcements?month='.$pm.'&year='.$py.
+ '<a href="/adm/announcements?month='.$pm.'&amp;year='.$py.
  ($pickdatemode?$pickinfo:'').'">'.&mt('Previous Month').'</a> '.
- '<a href="/adm/announcements?month='.$fm.'&year='.$fy.
+ '<a href="/adm/announcements?month='.$fm.'&amp;year='.$fy.
  ($pickdatemode?$pickinfo:'').'">'.&mt('Next Month').'</a>'.
  '&nbsp;&nbsp;&nbsp;<a href="/adm/announcements?month='.$todayhash{'month'}.
- '&year='.$todayhash{'year'}.
+ '&amp;year='.$todayhash{'year'}.
  ($pickdatemode?$pickinfo:'').'">'.&mt('Current Month').'</a></p>'.
- ($pickdatemode?'</font>':'').&Apache::loncommon::end_page());
-    $r->print('<a href="/adm/announcements.ics">'.&mt('Download your Calendar as iCalendar File').'</a>');
+ ($pickdatemode?'</font>':'').
+ '<a href="/adm/announcements.ics">'.&mt('Download your Calendar as iCalendar File').'</a>'.
+    &Apache::loncommon::end_page());
     return OK;
 } 
 
