@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Chat Fetching
 #
-# $Id: lonchatfetch.pm,v 1.34 2009/02/25 18:44:29 bisitz Exp $
+# $Id: lonchatfetch.pm,v 1.34.8.1 2010/11/18 23:23:01 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -63,7 +63,7 @@ sub handler {
 		'<b>'.&unescape($group_info{description}).
 		'</b><br />';
         }
-    } elsif (! &Apache::lonnet::allowed('pch',$env{'request.course.id'}.
+    } elsif (! &Apache::lonnet::allowed('plc',$env{'request.course.id'}.
              ($env{'request.course.sec'}?'/'.$env{'request.course.sec'}:''))
         ) {
         return HTTP_NOT_ACCEPTABLE;
