@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to set domain-wide configuration settings
 #
-# $Id: lonconfigsettings.pm,v 1.8.2.3 2010/05/22 13:26:21 raeburn Exp $
+# $Id: lonconfigsettings.pm,v 1.8.2.4 2010/11/19 13:09:36 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -141,7 +141,7 @@ sub print_footer {
     if (($phase eq 'display') || ($phase eq 'process')) {
         if (ref($actions) eq 'ARRAY') {
             foreach my $item (@{$actions}) {
-                $r->print('<input type="hidden" name="actions" value="'.$item.'" />')."\n";
+                $r->print('<input type="hidden" name="actions" value="'.$item.'" />'."\n");
             }
         }
     }
