@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Create a course
 #
-# $Id: loncreatecourse.pm,v 1.137 2010/04/13 21:19:15 raeburn Exp $
+# $Id: loncreatecourse.pm,v 1.137.4.1 2010/05/24 06:43:32 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -359,15 +359,21 @@ END
                  .'<label>'
                  .'<input type="radio" name="firstres" value="blank" />'.$lt{'blnk'}
                  .'</label>'
-                 .'&nbsp;'
-                 .'<label>'
+                 .'&nbsp;');
+    if ($crstype eq 'Community') {
+        $r->print('<label>'
+                 .'<input type="radio" name="firstres" value="nav" checked="checked" />'.$lt{'navi'}
+                 .'</label>');
+    } else {
+        $r->print('<label>'
                  .'<input type="radio" name="firstres" value="syl" checked="checked" />'.$lt{'sllb'}
                  .'</label>'
                  .'&nbsp;'
                  .'<label>'
                  .'<input type="radio" name="firstres" value="nav" />'.$lt{'navi'}
-                 .'</label>'
-                 .'<br />('.$lt{'stco'}.')'
+                 .'</label>');
+    }
+    $r->print('<br />('.$lt{'stco'}.')'
                  .&Apache::lonhtmlcommon::row_closure(1)
                  .&Apache::lonhtmlcommon::end_pick_box()
 
