@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # accessor routines used to provide information about course groups 
 #
-# $Id: longroup.pm,v 1.23 2010/01/30 18:19:16 raeburn Exp $
+# $Id: longroup.pm,v 1.27 2010/11/13 04:45:17 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -291,7 +291,8 @@ sub group_changes {
         }
        if (@changegroups > 0) {
             my %currpriv;
-            my %roleshash = &Apache::lonnet::dump('roles',$udom,$uname,$cid);
+            my $extra = &Apache::lonnet::freeze_escape({'skipcheck' => 1});
+            my %roleshash = &Apache::lonnet::dump('roles',$udom,$uname,$cid,undef,$extra);
 	    if (my $tmp = &Apache::lonnet::error(%roleshash)) {
                 &Apache::lonnet::logthis('Error retrieving roles: '.$tmp.
                                          ' for '.$uname.':'.$udom);
@@ -688,5 +689,24 @@ sub get_group_bbinfo {
 
 ###############################################
 
+sub get_group_link {
+    my ($cdom,$cnum,$group,$navmap) = @_;
+    if (ref($navmap)) {
+        my $symb = 'uploaded/'.$cdom.'/'.$cnum.'/group_folder_'.$group.'.sequence___1___adm/'.$cdom.'/'.$cnum.'/'.$group.'/smppg';
+        my $res = $navmap->getBySymb($symb);
+        my $link;
+        if (ref($res)) {
+            $link = $res->link();
+            $link .= (($link=~/\?/)?'&amp;':'?').'symb='.$res->shown_symb();
+        } else {
+            $link = '/adm/'.$cdom.'/'.$cnum.'/'.$group.'/smppg';
+        }
+        return $link; 
+    }
+    return;
+}
+
+###############################################
+
 1;
 
