@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Sending messages
 #
-# $Id: lonnotify.pm,v 1.32 2008/12/05 17:41:34 schafran Exp $
+# $Id: lonnotify.pm,v 1.35 2009/05/20 20:27:37 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -118,7 +118,7 @@ sub start_page {
 $start_page
 $breadcrumbs
 <br />
-<form name="$formname" method="POST">
+<form name="$formname" method="post">
 ENDONE
 
     return $output;
@@ -164,7 +164,7 @@ sub print_display_option_form {
     &Apache::lonhtmlcommon::add_breadcrumb({text=>"Display options"});
 
     my $cmd = 'display';
-    my $submit_text = 'Display e-mail';
+    my $submit_text = &mt('Display e-mail');
     my @roles = ('dc');
     my $now = time;
 
@@ -467,7 +467,7 @@ function setCourseCat(formname) {
     $output .= &Apache::lonhtmlcommon::role_select_row(\@roles,&mt('Roles'));
     $output .= &Apache::lonhtmlcommon::course_select_row(&mt('Courses'),$formname,$totcodes,\@codetitles,\%idlist,\%idlist_titles);
     $output .= &Apache::lonhtmlcommon::status_select_row(\%longtypes,&mt('Access status'));
-    $output .= &Apache::lonhtmlcommon::email_default_row(\%authtypes,&mt('Username -> Email conversion'),$descrip);
+    $output .= &Apache::lonhtmlcommon::email_default_row(\%authtypes,&mt('Username -> E-mail conversion'),$descrip);
     $output .= &Apache::lonhtmlcommon::submit_row(&mt('Submit'),$cmd,$submit_text);
     $output .= &Apache::lonhtmlcommon::end_pick_box();
     $output .= &end_page();
