@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # RSS Feeder
 #
-# $Id: lonrss.pm,v 1.39.2.2 2008/12/22 14:41:05 raeburn Exp $
+# $Id: lonrss.pm,v 1.47.8.1 2010/01/03 21:21:25 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -60,6 +60,9 @@ sub displayfeedname {
 # no, construct a name
     my $name=$filterfilename; 
     if ($name=~/^CourseBlog/) {
+        if ($env{'course.'.$env{'request.course.id'}.'.type'} eq 'Community') {
+            $name = &mt('Community Blog'); 
+        }
         $name=&mt('Course Blog');
 	if ($env{'course.'.$env{'request.course.id'}.'.description'}) {
 	    $name.=' '.$env{'course.'.$env{'request.course.id'}.'.description'};
@@ -322,13 +325,14 @@ sub handler {
         }
     }
     if ($html) {
-	my $title = $displayfeedname?$displayfeedname
-                                    :"Available RSS Feeds and Blogs";
+#	my $title = $displayfeedname?$displayfeedname:"Available RSS Feeds and Blogs";
+        my $title = "My Space";
 	my $rss_link = &Apache::lonrss::rss_link($uname,$udom);
+	my $brcrumb = [{href=>$rss_link,text=>"Available RSS Feeds and Blogs"}];
 	$r->print(&Apache::loncommon::start_page($title,$rss_link,
-						 {'domain'         => $udom,
-						  'force_register' =>
-						      $env{'form.register'}}).
+			 {'bread_crumbs'   => $brcrumb,
+			  'domain'         => $udom,
+			  'force_register' => $env{'form.register'}}).
 		  &changed_js());
     } else { # render RSS
         my $server = &Apache::lonnet::absolute_url();
@@ -389,9 +393,10 @@ sub handler {
 	}
 # Add a new feed
         if (($html) && ($edit)) {
+	    $r->print('<h4>' . &mt('New RSS Feed or Blog'). '</h4>');
 	    $r->print('<form method="post" name="makenewfeed">');
-            $r->print(&mt('Name for New Feed').": <input type='text' size='40' name='namenewblog' />");
-	    $r->print('<input type="submit" value="'.&mt('Start a New Feed').'" />');
+            $r->print(&mt('Name').": <input type='text' size='40' name='namenewblog' />");
+	    $r->print('<input type="submit" value="'.&mt('New Feed').'" />');
 	    $r->print('</form>');
 	}
         if ($displayfeedname) { # this is an existing feed
@@ -508,7 +513,7 @@ sub handler {
 							   'private' => 'private',
 							   'hidden' => 'hidden',
 							   'delete' => 'delete',
-							   'store' => 'Save changes',
+							   'store' => 'Select',
 							   'title' => 'Title',
 							   'link' => 'Link',
 							   'description' => 'Description',
@@ -588,7 +593,7 @@ ENDEDIT
 	    if ($html) {
 		$r->print('</ul>');
 		if ($edit) {
-		    $r->print('<input type="hidden" name="newid" value="'.$newid.'"/><input type="submit" value="'.&mt('Save Marked Changes').'" />'.
+		    $r->print('<input type="hidden" name="newid" value="'.$newid.'"/><input type="submit" value="'.&mt('Save Selected').'" />'.
 			      ($displayoption eq 'hidden'?'<input type="submit" name="advertisethisblog" value="'.&mt('Advertise this Feed').'" />':
 			       '<input type="submit" name="hidethisblog" value="'.&mt('Hide this Feed').'" />'));
 		}
