@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to display the classlist 
 #
-# $Id: lonviewclasslist.pm,v 1.10 2008/03/12 02:45:07 raeburn Exp $
+# $Id: lonviewclasslist.pm,v 1.12 2009/10/17 03:11:25 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -91,9 +91,9 @@ ENDHEADER
     if (keys(%viewsettings) > 0) {
         $r->print(&html_classlist($r,\%viewsettings));
     } else {
-        $r->print('<h3>'.
+        $r->print('<div class="LC_info">'.
                   &mt("Display of a student-viewable course roster is not currently enabled.").
-                  '</h3>');
+                  '</div>');
     }
     #
     # Finish up
@@ -262,7 +262,7 @@ sub html_classlist {
             '<td>'.('&nbsp;'x2).
             &Apache::loncommon::messagewrapper
             ('<img src="/adm/lonIcons/mailto.gif" border="0" />&nbsp;'.
-             $username.'@'.$domain,$username,$domain).'</td>';
+             $username.':'.$domain,$username,$domain).'</td>';
         if (! $viewsettings->{'limit_to_section'}) {
             $Str .= '<td>'.$section.'</td>';
         }
