@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
-# $Id: printout.pl,v 1.142.6.3 2010/05/11 12:10:25 raeburn Exp $
+# $Id: printout.pl,v 1.142.6.4 2010/08/26 08:45:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -467,19 +467,12 @@ foreach $texfile (@texfile) {
 	      my $ps_file = my $tempo_file = $1.'temporar.ps';
 	      my $pdf_file = $1.'.pdf';
 	      $papera=~s/t/p/;
-              $comma = "fixps --force $new_name_file";
-              &debug("FIXPS command: $comma");
-              &busy_wait_command("$comma 1>/dev/null 2>/dev/null",
-                                 "for $status_statement now validating PS",
-                                 \%prog_state,$tempo_file);
 	      if ($laystyle eq 'album' and $numberofcolumns eq '2') {
 		  $comma = "psnup $papera -2 -s1.0 $new_name_file";
 		  &debug("PSNUP command: $comma");
-                  &busy_wait_command("$comma 1>$tempo_file 2>/dev/null",
+                  &busy_wait_command("$comma $tempo_file 1>/dev/null 2>/dev/null",
 				     "for $status_statement now Modifying PS layout",
 				     \%prog_state,$tempo_file);
-	          &busy_wait_command("mv $tempo_file $new_name_file",
-				     'File move', \%prog_state, $new_name_file);
 	      } elsif ($laystyle eq 'book' and $numberofcolumns eq '2') {
 		  $comma = 'pstops '.$papera.' "2:0+1(0.48w,0)" '.$new_name_file;
 		  &debug("PSTOPS command: $comma ");
