@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for requesting to have slots added to a students record
 #
-# $Id: slotrequest.pm,v 1.106 2009/11/04 15:37:23 raeburn Exp $
+# $Id: slotrequest.pm,v 1.107 2010/05/27 04:44:33 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -847,7 +847,7 @@ sub show_choices {
 		      (keys(%slots)))  {
 
 	&Apache::lonxml::debug("Checking Slot $slot");
-	next if (!&allowed_slot($slot,$slots{$slot},undef,\%slots,
+	next if (!&allowed_slot($slot,$slots{$slot},$symb,\%slots,
 				$consumed_uniqueperiods));
 
         push(@available,$slot);
