@@ -1,5 +1,5 @@
 #
-# $Id: Spreadsheet.pm,v 1.78 2008/03/12 02:45:27 raeburn Exp $
+# $Id: Spreadsheet.pm,v 1.80 2008/09/12 14:35:46 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1525,16 +1525,16 @@ sub outsheet_csv   {
     my $csvdata = '';
     my @Values;
     #
-    # Open the csv file
+    # Open the CSV file
     my $filename = '/prtspool/'.
         $env{'user.name'}.'_'.$env{'user.domain'}.'_'.
         time.'_'.rand(1000000000).'.csv';
     my $file;
     unless ($file = Apache::File->new('>'.'/home/httpd'.$filename)) {
         $r->log_error("Couldn't open $filename for output $!");
-        $r->print(&mt("Problems occured in writing the csv file.  ".
-                  "This error has been logged.  ".
-                  "Please alert your LON-CAPA administrator."));
+        $r->print(&mt('Problems occurred in writing the CSV file. '
+                     .'This error has been logged. '
+                     .'Please alert your LON-CAPA administrator.'));
         $r->print("<pre>\n".$csvdata."</pre>\n");
         return 0;
     }
@@ -1547,7 +1547,7 @@ sub outsheet_csv   {
     # Output the body of the spreadsheet
     $self->csv_rows($connection,$file);
     #
-    # Close the csv file
+    # Close the CSV file
     close($file);
     $r->print('<br /><br />'.
               '<a href="'.$filename.'">'.&mt('Your CSV spreadsheet.').'</a>'."\n");
