@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstathelpers.pm,v 1.56 2008/10/30 17:45:25 bisitz Exp $
+# $Id: lonstathelpers.pm,v 1.59 2009/05/06 16:19:42 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -158,14 +158,14 @@ sub problem_selector {
                                                      resptype=>$resptype});
                         my $checked = '';
                         if ($env{'form.problemchoice'} eq $value) {
-                            $checked = 'checked="checked" ';
+                            $checked = ' checked="checked"';
                         }
                         my $title = $res->compTitle;
                         if (! defined($title) || $title eq '') {
                             ($title) = ($res->src =~ m:/([^/]*)$:);
                         }
                         $seq_str .= '<tr>'.
-                            qq{<td><input type="radio" id="$rb_count" name="problemchoice" value="$value" $checked /></td>}.
+                            qq{<td><input type="radio" id="$rb_count" name="problemchoice" value="$value"$checked /></td>}.
                             '<td><label for="'.$rb_count.'">'.$resptype.'</label></td>'.
                             '<td><label for="'.$rb_count.'">'.$title.'</label>';
                         if (scalar(@response_ids) > 1) {
@@ -181,12 +181,12 @@ sub problem_selector {
             }
         }
         if ($seq_str ne '') {
-            $Str .= '<tr><td>&nbsp</td>'.
+            $Str .= '<tr><td>&nbsp;</td>'.
                 '<td colspan="2"><b>'.$seq->compTitle.'</b></td>'.
                 "</tr>\n".$seq_str;
             if (defined($sequence_addendum)) {
                 $Str .= '<tr>'.
-                    ('<td>&nbsp</td>'x2).
+                    ('<td>&nbsp;</td>'x2).
                     '<td align="right">'.$sequence_addendum.'</td>'.
                     "</tr>\n";
             }
@@ -238,7 +238,7 @@ sub MultipleProblemSelector {
     my $selected = {map { ($_,1) } (&get_selected_symbs($inputname))};
     # Header
     $Str .= <<"END";
-<script language="JavaScript" type="text/javascript">
+<script type="text/javascript" language="JavaScript">
     function checkall(value,seqid) {
         for (i=0; i<document.forms.$formname.elements.length; i++) {
             ele = document.forms.$formname.elements[i];
@@ -1255,7 +1255,7 @@ sub limit_by_time_form {
     my $enddateform = &Apache::lonhtmlcommon::date_setter
         ('Statistics','limitby_enddate',$endtime,undef,undef,$state);
     my $Str;
-    $Str .= '<script language="Javascript" >';
+    $Str .= '<script type="text/javascript" language="JavaScript">';
     $Str .= 'function toggle_limitby_activity(state) {';
     $Str .= '    if (state) {';
     $Str .= '        limitby_startdate_enable();';
@@ -1420,7 +1420,7 @@ sub submission_report_form {
              ' enough input.');
     }
     my $html = $/.
-        '<script type="Text/JavaScript">'.
+        '<script type="text/javascript" language="JavaScript">'.
         "document.Statistics.reportSelected.value='$original_report';".
         '</script>'.
         '<input type="hidden" name="correctans" value="true" />'.
