@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonsubmissiontimeanalysis.pm,v 1.28 2006/12/21 19:52:28 albertel Exp $
+# $Id: lonsubmissiontimeanalysis.pm,v 1.31 2008/12/11 14:55:27 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -71,7 +71,10 @@ sub BuildSubmissionTimePage {
     my @Students = @Apache::lonstatistics::Students;
     #
     if (@Students < 1) {
-        $r->print('<h2>There are no students in the sections selected</h2>');
+        $r->print('<div class="LC_warning">'
+                 .&mt('There are no students in the sections selected.'
+                 .'</div>')
+        );
     }
     #
     my @CacheButtonHTML = 
@@ -81,7 +84,8 @@ sub BuildSubmissionTimePage {
     if (! exists($env{'form.problemchoice'}) ||
         exists($env{'form.SelectAnother'})) {
         my $submit_button = '<input type="submit" name="" value="'.
-            &mt('Graph Problem Submission Times').'" />';
+#           &mt('Graph Problem Submission Times').'" />';
+            &mt('Generate Graph').'" />';
         $r->print($submit_button.'&nbsp;'x5);
         $r->print('<h3>'.&mt('Please select a problem to analyze').'</h3>');
         $r->print(&Apache::lonstathelpers::problem_selector('.',
@@ -124,7 +128,10 @@ sub BuildSubmissionTimePage {
         #
         my $resource = $current_problem->{'resource'};
         if (! defined($resource)) {
-            $r->print('resource is undefined');
+            $r->print('<div class="LC_warning">'
+                     .&mt('Resource is undefined.')
+                     .'</div>'
+            );
         } else {
             $r->print('<h1>'.$resource->compTitle.'</h1>');
             $r->print('<h3>'.$resource->src.'</h3>');
@@ -132,8 +139,9 @@ sub BuildSubmissionTimePage {
                  &Apache::lonstatistics::section_and_enrollment_description().
                       '</h4>');
             $r->rflush();
+            $r->print('<hr />');
             $r->print(&Apache::lonstathelpers::render_resource($resource));
-            $r->print('<br />');
+            $r->print('<hr /><br />');
             $r->rflush();
 	    if (@Students) {	    
 		$r->print(&analyze_times($r,$resource->symb,\@Students,
@@ -180,12 +188,16 @@ sub analyze_times {
          $Apache::lonstatistics::enrollment_status,
          $symb,$part);
     if (! defined($SubData) || ! ref($SubData)) {
-        $html.= '<h2>There is no submission data for this problem at all</h2>';
+        $html.= '<div class="LC_warning">'
+               .&mt('There is no submission data for this problem at all.')
+               .'</div>';
         return $html;
     }
     my $NumSub = scalar(@{$SubData});
     if (! @{$SubData}) {
-        $html.= '<h2>There is no submission data for this problem</h2>';
+        $html.= '<div class="LC_warning">'
+               .&mt('There is no submission data for this problem.')
+               .'</div>';
         return $html;
     }
     # Process the data
@@ -295,13 +307,13 @@ sub analyze_times {
             next if (! defined($BinEnd[$i]) || $BinEnd[$i] == 0);
             $htmltable .= 
                 '<tr>'.
-                '<td align="right"><nobr>'.
+                '<td align="right"><span class="LC_nobreak">'.
                 &Apache::lonlocal::locallocaltime($BinEnd[$i]-$binsize).
-                '</nobr></td>'.
+                '</span></td>'.
                 '<td>&nbsp;</td>'.
-                '<td align="right"><nobr>'.
+                '<td align="right"><span class="LC_nobreak">'.
                     &Apache::lonlocal::locallocaltime($BinEnd[$i]).'</td>'.
-                '</nobr></td>'.
+                '</span></td>'.
                 '<td align="right">'.$Ydata[$i].('&nbsp;'x3).'</td>'.
                 '<td>&nbsp;</td>'.
                 '<td align="right">'.$AnsData[$i].('&nbsp;'x3).'</td>'.
@@ -400,15 +412,16 @@ sub CreateInterface {
     my $Str = '';
     $Str .= &Apache::lonhtmlcommon::breadcrumbs('Submission Time Plots');
     $Str .= '<p>';
-    $Str .= '<table cellspacing="5">'."\n";
-    $Str .= '<tr>';
-    $Str .= '<th align="center">'.&mt('Sections').'</th>';
-    $Str .= '<th align="center">'.&mt('Groups').'</th>';
-    $Str .= '<th align="center">'.&mt('Access Status').'</th>';
-    $Str .= '</tr>'."\n";
+    $Str .= &Apache::loncommon::start_data_table();
+    $Str .= &Apache::loncommon::start_data_table_header_row();
+    $Str .= '<th>'.&mt('Sections').'</th>';
+    $Str .= '<th>'.&mt('Groups').'</th>';
+    $Str .= '<th>'.&mt('Access Status').'</th>';
+    $Str .= &Apache::loncommon::end_data_table_header_row();
     ##
     ## 
-    $Str .= '<tr><td align="center">'."\n";
+    $Str .= &Apache::loncommon::start_data_table_row();
+    $Str .= '<td align="center">'."\n";
     $Str .= &Apache::lonstatistics::SectionSelect('Section','multiple',4);
     $Str .= '</td>';
     #
@@ -420,13 +433,15 @@ sub CreateInterface {
     $Str .= &Apache::lonhtmlcommon::StatusOptions(undef,undef,4);
     $Str .= '</td>';
     #
-    $Str .= '</tr>'."\n";
-    $Str .= '</table>'."\n";
+    $Str .= &Apache::loncommon::end_data_table_row();
+    $Str .= &Apache::loncommon::end_data_table();
     #
-    $Str .= '<nobr>'.&mt('Status: [_1]',
-                         '<input type="text" '.
-                         'name="stats_status" size="60" value="" />').
-            '</nobr>'.'</p>';
+    $Str .= '<p><span class="LC_nobreak">'
+           .&mt('Status: [_1]',
+                    '<input type="text" name="stats_status"'
+                   .' size="60" value="" readonly="readonly" />')
+           .'</span></p>';
+    $Str .= '</p>';
     ##
     return $Str;
 }
