@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to cleanup XML files
 #
-# $Id: loncleanup.pm,v 1.9 2006/12/20 22:41:08 albertel Exp $
+# $Id: loncleanup.pm,v 1.10 2008/12/24 07:58:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -335,7 +335,7 @@ sub handler {
 
     if ($env{'form.filename'}) {
 	$fn=$env{'form.filename'};
-	$fn=~s/^http\:\/\/[^\/]+//;
+	$fn=~s/^https?\:\/\/[^\/]+//;
     } else {
 	$r->log_reason($env{'user.name'}.' at '.$env{'user.domain'}.
 		       ' unspecified filename for cleanup', $r->filename); 
