@@ -2,7 +2,7 @@
 # The LearningOnline Network with CAPA
 # Handler to upload files into construction space
 #
-# $Id: lonupload.pm,v 1.38.2.3 2008/12/21 04:43:41 raeburn Exp $
+# $Id: lonupload.pm,v 1.46.6.1 2009/10/07 21:09:21 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -28,6 +28,92 @@
 #
 ###
 
+=head1 NAME
+
+Apache::lonupload - upload files into construction space
+
+=head1 SYNOPSIS
+
+Invoked by /etc/httpd/conf/srm.conf:
+
+ <Location /adm/upload>
+ PerlAccessHandler       Apache::lonacc
+ SetHandler perl-script
+ PerlHandler Apache::lonupload
+ ErrorDocument     403 /adm/login
+ ErrorDocument     404 /adm/notfound.html
+ ErrorDocument     406 /adm/unauthorized.html
+ ErrorDocument	  500 /adm/errorhandler
+ </Location>
+
+=head1 INTRODUCTION
+
+This module uploads a file sitting on a client computer into 
+library server construction space.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 HANDLER SUBROUTINE
+
+This routine is called by Apache and mod_perl.
+
+=over 4
+
+=item *
+
+Initialize variables
+
+=item *
+
+Start page output
+
+=item *
+
+output relevant interface phase (phaseone or phasetwo or phasethree)
+
+=item *
+
+(phase one is to specify upload file; phase two is to handle conditions
+subsequent to specification--like overwriting an existing file; phase three
+is to handle processing of secondary uploads - of embedded objects in an
+html file).
+
+=back
+
+=head1 OTHER SUBROUTINES
+
+=over
+
+=item phaseone()
+
+Interface for specifying file to upload.
+
+=item phasetwo()
+
+Interface for handling post-conditions about uploading (such
+as overwriting an existing file).
+
+=item phasethree()
+
+Interface for handling secondary uploads of embedded objects
+in an html file.
+
+=item upfile_store()
+
+Store contents of uploaded file into temporary space.  Invoked
+by phaseone subroutine.
+
+=item check_extension()
+
+Checks if filename extension is permitted and checks type
+ of file - if html file, calls parser to check for embedded objects.
+ Invoked by phasetwo subroutine.
+
+=back
+
+=cut
+
 package Apache::lonupload;
 
 use strict;
@@ -99,33 +185,33 @@ sub phaseone {
 		      &upfile_store.'" />'.
 		      '<input type="hidden" name="uploaduname" value="'.$uname.
 		      '" />'.&mt('Save uploaded file as [_1]',
-                      '<span class="LC_filename">/priv/'.$uname.'/</span>'.
+                      "<span class='LC_filename'>/priv/$uname/</span>".
                       '<input type="text" size="50" name="filename" value="'.$fn.
                       '" />').
                       '<br />'.
 		      '<br />'.&mt('Choose file type:').'
 <select name="filetype">
- <option value="standard" selected>'.&mt('Regular file').'
- <option value="testbank">'.&mt('Testbank file').'
- <option value="imsimport">'.&mt('IMS package').'
+ <option value="standard" selected="selected">'.&mt('Regular file').'</option>
+ <option value="testbank">'.&mt('Testbank file').'</option>
+ <option value="imsimport">'.&mt('IMS package').'</option>
 </select>'.&Apache::loncommon::help_open_topic("Uploading_File_Options").'
 <br />
 <br />
 ');
-            $r->print('<input type="button" value="'.&mt('Save').'" onClick="javascript:verifyForm()"/></form>');
+            $r->print('<input type="button" value="'.&mt('Upload').'" onclick="javascript:verifyForm()"/></form>');
 	    # Check for bad extension and warn user
 	    if ($fn=~/\.(\w+)$/ && 
 		(&Apache::loncommon::fileembstyle($1) eq 'hdn')) {
-		$r->print('<p class="LC_error">'
-                          .&mt('The extension on this file, [_1], is reserved internally by LON-CAPA.','"'.$1.'"' )
-			  .' <br />'.&mt('Please change the extension.')
+                $r->print('<p class="LC_error">'
+                          .&mt('The extension on this file, [_1], is reserved internally by LON-CAPA.','"'.$1.'"')
+                          .' <br />'.&mt('Please change the extension.')
                           .'</p>');
 	    } elsif($fn=~/\.(\w+)$/ && 
 		    !defined(&Apache::loncommon::fileembstyle($1))) {
-		$r->print('<p class="LC_error">'
-                          .&mt('The extension on this file, [_1], is not recognized by LON-CAPA.','"'.$1.'"')
-			  .' <br />'.&mt('Please change the extension.')
-			  .'</p>');
+                $r->print('<p class="LC_error">'
+                         .&mt('The extension on this file, [_1], is not recognized by LON-CAPA.','"'.$1.'"')
+                         .' <br />'.&mt('Please change the extension.')
+                         .'</p>');
 	    }
 	} else {
 	    $r->print('<span class="LC_error">'.&mt('Illegal filename.').'</span>');
@@ -358,8 +444,10 @@ function verifyForm() {
 					     $javascript));
   
     if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
-	$r->print('<h3><span class="LC_error">'.&mt('Co-Author').': '.$uname.
-		  &mt(' at ').$udom.'</span></h3>');
+        $r->print('<p class="LC_warning">'
+                 .&mt('Co-Author [_1]',$uname.':'.$udom)
+                 .'</p>'
+        );
     }
 
     if ($env{'form.phase'} eq 'three') {
@@ -379,88 +467,4 @@ function verifyForm() {
 1;
 __END__
 
-=head1 NAME
 
-Apache::lonupload - upload files into construction space
-
-=head1 SYNOPSIS
-
-Invoked by /etc/httpd/conf/srm.conf:
-
- <Location /adm/upload>
- PerlAccessHandler       Apache::lonacc
- SetHandler perl-script
- PerlHandler Apache::lonupload
- ErrorDocument     403 /adm/login
- ErrorDocument     404 /adm/notfound.html
- ErrorDocument     406 /adm/unauthorized.html
- ErrorDocument	  500 /adm/errorhandler
- </Location>
-
-=head1 INTRODUCTION
-
-This module uploads a file sitting on a client computer into 
-library server construction space.
-
-This is part of the LearningOnline Network with CAPA project
-described at http://www.lon-capa.org.
-
-=head1 HANDLER SUBROUTINE
-
-This routine is called by Apache and mod_perl.
-
-=over 4
-
-=item *
-
-Initialize variables
-
-=item *
-
-Start page output
-
-=item *
-
-output relevant interface phase (phaseone or phasetwo or phasethree)
-
-=item *
-
-(phase one is to specify upload file; phase two is to handle conditions
-subsequent to specification--like overwriting an existing file; phase three
-is to handle processing of secondary uploads - of embedded objects in an
-html file).
-
-=back
-
-=head1 OTHER SUBROUTINES
-
-=over 4
-
-=item *
-
-phaseone() : Interface for specifying file to upload.
-
-=item *
-
-phasetwo() : Interface for handling post-conditions about uploading (such
-as overwriting an existing file).
-
-=item *
-
-phasethree() : Interface for handling secondary uploads of embedded objects
-in an html file.
-
-=item *
-
-upfile_store() : Store contents of uploaded file into temporary space.  Invoked
-by phaseone subroutine.
-
-=item *
-
-check_extension() : Checks if filename extension is permitted and checks type
- of file - if html file, calls parser to check for embedded objects.
- Invoked by phasetwo subroutine.
-
-=back
-
-=cut
