@@ -1,5 +1,5 @@
 # Handler for parsing text upload problem descriptions into .problems
-# $Id: testbankimport.pm,v 1.19 2008/12/19 03:53:00 raeburn Exp $
+# $Id: testbankimport.pm,v 1.24 2009/05/14 14:24:18 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -81,14 +81,14 @@ function createWin() {
     newWindow = window.open("","CreateDir","HEIGHT=400,WIDTH=750,scrollbars=yes")
     newWindow.document.open()
     newWindow.document.write('$start_page')
-    newWindow.document.write("<img border='0' src='/adm/lonInterFace/author.jpg' alt='[Author Header]'>\\n")
+    newWindow.document.write("<img border='0' src='/adm/lonInterFace/author.jpg' alt='[Author Header]' />\\n")
     newWindow.document.write("<h3>$lt{'loca'}: <tt>$webpath</tt></h3><h3>$lt{'newd'}</h3>\\n")
     newWindow.document.write("<form name='fileaction' action='/adm/cfile' method='post'>\\n")
     newWindow.document.write("$lt{'ente'}.<br /><br />")
-    newWindow.document.write("<input type='hidden' name='filename' value='$webpath'>")
-    newWindow.document.write("<input type='hidden' name='action' value='newdir'>")
-    newWindow.document.write("<input type='hidden' name='callingmode' value='testbank'>")
-    newWindow.document.write("$webpath<input type='text' name='newfilename' value=''/>")
+    newWindow.document.write("<input type='hidden' name='filename' value='$webpath' />")
+    newWindow.document.write("<input type='hidden' name='action' value='newdir' />")
+    newWindow.document.write("<input type='hidden' name='callingmode' value='testbank' />")
+    newWindow.document.write("$webpath<input type='text' name='newfilename' value='' />")
     newWindow.document.write("<input type='button' value='$lt{'go'}' onClick='document.fileaction.submit();' /></form>")
     newWindow.document.write('$end_page')
     newWindow.document.close()
@@ -510,7 +510,7 @@ sub display_zero {
         </ol><form name="info" method="post" action="/adm/testbank">'.
         &topic_bar(1,&mt('Optional: create a sub-directory in which the testbank questions will be saved')).
         &mt('By default, LON-CAPA problems generated from the testbank file will be stored in the current directory.').' '.&mt('To store them in a new sub-directory:'). 
-       ' <input type="button" name="createdir" value="'.&mt('Create sub-directory').'" onClick="javascript:createWin()">'.
+       ' <input type="button" name="createdir" value="'.&mt('Create sub-directory').'" onClick="javascript:createWin()" />'.
        &page_footer($env{'form.newdir'},$uname,$fn,$page,$webpath).'
        </form>');
 }
@@ -522,7 +522,7 @@ sub display_one {
     my %topics;
     $topics{2} = &mt('Select the format of the question number - e.g., 1,  1., 1), (1 or (1) - ').'&nbsp;
                <select name="qnumformat">
-                  <option value = "-1" selected>'.&mt('Select').'</option>
+                  <option value="-1" selected="selected">'.&mt('Select').'</option>
                   <option value="number">1</option>
                   <option value="period">1.</option>
                   <option value="paren">(1)</option>
@@ -625,10 +625,10 @@ sub display_two {
         $r->print(&Apache::loncommon::start_data_table_row().
                  '<td valign="top">&nbsp;'.$iter.'&nbsp;</td>'."\n".
                  '<td valign="top">&nbsp;<input type="text" name="start_'.$i.'" value="'.$bl1st.'" size="5" />&nbsp;</td>'."\n".
-                 '<td valign="top">&nbsp;<input type="text" name="end_'.$i.'" value="'.$bl1end.'" size="5">&nbsp;</td>'."\n".
+                 '<td valign="top">&nbsp;<input type="text" name="end_'.$i.'" value="'.$bl1end.'" size="5" />&nbsp;</td>'."\n".
                  '<td valign="top">
    <select name="qtype_'.$i.'" onChange="colSet('.$i.')">
-    <option value= "-1" selected>'.&mt('Select').'</option>'."\n");
+    <option value="-1" selected="selected">'.&mt('Select').'</option>'."\n");
         foreach my $qtype (@types) {
             $r->print('<option value="'.$qtype.'">'.$typenames{$qtype}.'</option>'."\n");
         }
@@ -768,7 +768,7 @@ sub display_three {
                                 }
                                 $r->print(&Apache::loncommon::start_data_table_row().
                                           '<td valign="top">'.$qnum.'.</td>'."\n".
-                                          '<td valign="top"><input name="createprob" type="checkbox" "checked="checked" value="'.$j.'" /></td>'."\n".
+                                          '<td valign="top"><input name="createprob" type="checkbox" checked="checked" value="'.$j.'" /></td>'."\n".
                                           '<td valign="top"><b>'.$qtype[$i].'</b></td>'."\n".
                                           '<td valign="top"><input type="textbox" name="probfile_'.$j.'" value="'.$libfile.'" size="20" /></td>'.
                                           '<td valign="top">'.$showqn.'<br /><br />'."\n");
@@ -829,7 +829,7 @@ sub display_three {
                         }
                         $r->print(&Apache::loncommon::start_data_table_row().
                                   '<td valign="top">'.$qnum.'</td>'."\n".
-                                  '<td valign="top"><input name="createprob" type="checkbox" "checked="checked" value="'.$j.'" /></td>'."\n".
+                                  '<td valign="top"><input name="createprob" type="checkbox" checked="checked" value="'.$j.'" /></td>'."\n".
                                   '<td valign="top"><b>'.$qtype[$i].'</b></td>'."\n".
                                   '<td valign="top"><input type="textbox" name="probfile_'.$j.'" value="'.$libfile.'" size="20" /></td>'."\n".
                                   '<td valign="top">'.$items->[$j].'</td>'."\n".
@@ -1200,7 +1200,7 @@ sub page_footer {
             $output .= '
          <td>&nbsp;</td>
          <td>
-          <input type="button" name="nextpage" value="'.$nextval.'" onclick="'.$nextclick.'">
+          <input type="button" name="nextpage" value="'.$nextval.'" onclick="'.$nextclick.'" />
          </td>';
         }
         $output .= '    </tr>
@@ -1773,8 +1773,9 @@ sub print_header {
     my $output = &Apache::loncommon::start_page($title,$javascript,
                                              {'add_entries' => $loadentries});
     if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
-        $output .= '<h3><span class="LC_error">'.&mt('Co-Author').': '.$uname.
-                   &mt(' at ').$udom.'</span></h3>';
+        $output .= '<p class="LC_warning">'
+                 .&mt('Co-Author [_1]',$uname.':'.$udom)
+                 .'</p>';
     }
     return $output;
 }
