@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.148.2.2 2009/03/18 14:05:19 raeburn Exp $
+# $Id: lonplot.pm,v 1.152 2009/11/14 19:13:36 faziophi Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,9 @@
 # http://www.lon-capa.org/
 #
 
+
+
+
 package Apache::lonplot;
 
 use strict;
@@ -57,6 +60,8 @@ BEGIN {
 }
 
 
+=pod
+
 ## 
 ## Description of data structures:
 ##
@@ -88,6 +93,8 @@ BEGIN {
 ##                                                               ##
 ###################################################################
 
+=cut
+
 my $max_str_len = 50;    # if a label, title, xlabel, or ylabel text
                          # is longer than this, it will be truncated.
 
@@ -448,7 +455,7 @@ my %tic_defaults =
 	 },         
      );
 
-my @axis_edit_order = ('color','xmin','xmax','ymin','ymax','xformat', 'yformat');
+my @axis_edit_order = ('color','xmin','xmax','ymin','ymax','xformat', 'yformat', 'xzero', 'yzero');
 my %axis_defaults = 
     (
      color   => {
@@ -500,7 +507,22 @@ my %axis_defaults =
          edit_type   => 'choice',
          choices     => ['on', 'off', '2e', '2f'],
          },
-
+     
+     xzero => {
+     	default => 'off',
+     	test	=> sub {$_[0]=~/^(off|line|thick-line|dotted)$/},
+     	description => 'Show x-zero (y=0) axis',
+     	edit_type  => 'choice',
+     	choices	=> ['off', 'line', 'thick-line', 'dotted'],
+     	},
+     
+     yzero => {
+     	default => 'off',
+     	test	=> sub {$_[0]=~/^(off|line|thick-line|dotted)$/},
+     	description => 'Show y-zero (x=0) axis',
+     	edit_type  => 'choice',
+     	choices	=> ['off', 'line', 'thick-line', 'dotted'],
+     	},
      );
 
 my @curve_edit_order = ('color','name','linestyle','linewidth','linetype','pointtype','pointsize','limit');
@@ -1728,6 +1750,26 @@ sub write_gnuplot_file {
         }
 	$gnuplot_input .= "set xrange \[$axis{'xmin'}:$axis{'xmax'}\]\n";
 	$gnuplot_input .= "set yrange \[$axis{'ymin'}:$axis{'ymax'}\]\n";
+		if ($axis{'xzero'} ne 'off') {
+			$gnuplot_input .= "set xzeroaxis ";
+			if ($axis{'xzero'} eq 'line' || $axis{'xzero'} eq 'thick-line') {
+				$gnuplot_input .= "lt -1 ";
+				if ($axis{'xzero'} eq 'thick-line') {
+					$gnuplot_input .= "lw 3 ";
+				}
+			}
+			$gnuplot_input .= "\n";
+		}
+		if ($axis{'yzero'} ne 'off') {
+			$gnuplot_input .= "set yzeroaxis ";
+			if ($axis{'yzero'} eq 'line' || $axis{'yzero'} eq 'thick-line') {
+				$gnuplot_input .= "lt -1 ";
+				if ($axis{'yzero'} eq 'thick-line') {
+					$gnuplot_input .= "lw 3 ";
+				}
+			}
+			$gnuplot_input .= "\n";
+		}
     }
     # Key
     if (%key) {
@@ -2016,3 +2058,118 @@ sub insert_data {
 __END__
 
 
+=head1 NAME
+
+Apache::lonplot.pm
+
+=head1 SYNOPSIS
+
+XML-based plotter of graphs
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=head1 SUBROUTINES (parsing and edit rendering)
+
+=over
+
+=item start_gnuplot()
+
+=item end_gnuplot()
+
+=item start_xtics()
+
+=item end_xtics()
+
+=item start_ytics()
+
+=item end_ytics()
+
+=item get_font()
+
+=item start_key()
+
+=item end_key()
+
+=item parse_label()
+
+=item replace_entities()
+
+=item start_title()
+
+=item end_title()
+
+=item start_xlabel()
+
+=item end_xlabel()
+
+=item start_ylabel()
+
+=item end_label()
+
+=item start_curve()
+
+=item end_curve()
+
+=item start_function()
+
+=item end_function()
+
+=item start_data()
+
+=item end_data()
+
+=item start_axis()
+
+=item end_axis
+
+=back
+
+=head1 SUBROUTINES (Utility)
+
+=over
+
+=item set_defaults()
+
+=item get_attributes()
+
+=item write_gnuplot_file()
+
+=item check_inputs()
+
+=item edit_attributes()
+
+=back
+
+=head1 SUBROUTINES (Insertion functions for editing plots)
+
+=over
+
+=item insert_gnuplot()
+
+=item insert_tics()
+
+=item insert_xtics()
+
+=item insert_key()
+
+=item insert_axis()
+
+=item insert_title()
+
+=item insert_xlabel()
+
+=item insert_ylabel()
+
+=item insert_label()
+
+=item insert_curve()
+
+=item insert_function()
+
+=item insert_data()
+
+=back
+
+=cut
