@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # <script> definiton
 #
-# $Id: scripttag.pm,v 1.148.2.1 2008/12/11 21:30:10 raeburn Exp $
+# $Id: scripttag.pm,v 1.151 2008/12/11 21:28:59 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -612,3 +612,20 @@ sub end_algebra {
 
 1;
 __END__
+
+=pod
+
+=head1 NAME
+
+Apache::scripttag.pm
+
+=head1 SYNOPSIS
+
+implements <script>, <scriptlib>, <parserlib>,
+and <import>
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=cut
+
