@@ -2,7 +2,7 @@
 #
 # Page flip handler
 #
-# $Id: lonpageflip.pm,v 1.75.2.1 2008/12/21 05:00:52 raeburn Exp $
+# $Id: lonpageflip.pm,v 1.79 2009/04/23 17:31:25 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -27,6 +27,8 @@
 # http://www.lon-capa.org/
 #
 
+
+
 package Apache::lonpageflip;
 
 use strict;
@@ -476,7 +478,7 @@ $start_page
 <p>
 $lt{'pick'}:
 <p>
-<table border=2>
+<table border="2">
 <tr><th>$lt{'titleheader'}</th><th>$lt{'type'}</th></tr>
 ENDSTART
                      foreach my $id (@possibilities) {
@@ -528,6 +530,46 @@ ENDMENU
 1;
 __END__
 
+=pod
+
+=head1 NAME
+
+Apache::lonpageflip
+
+=head1 SYNOPSIS
+
+Deals with forward, backward, and other page flips.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 OVERVIEW
+
+(empty)
+
+=head1 SUBROUTINES
+
+=over cleanup()
+
+=item addrid()
+
+=item fullmove()
+
+=item hash_src()
+
+=item move()
+
+=item get_next_possible_move()
+
+=item navlaunch()
+
+=item first_accessible_resource()
+
+=item handler()
+
+=back
+
+=cut
 
 
 
