@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Wrapper for external and binary files as standalone resources
 #
-# $Id: lonwrapper.pm,v 1.28.2.1 2008/12/21 04:49:58 raeburn Exp $
+# $Id: lonwrapper.pm,v 1.32.2.2 2010/02/11 15:12:11 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,7 @@
 # http://www.lon-capa.org/
 #
 
+
 package Apache::lonwrapper;
 
 use strict;
@@ -144,8 +145,11 @@ sub handler {
 #
 	if ($is_ext) {
 	    $ENV{'QUERY_STRING'}=~s/(^|\&)symb=[^\&]*/$1/;
+            $ENV{'QUERY_STRING'} =~ s/\&$//;
 	}
-	$url.=(($url=~/\?/)?'&':'?').$ENV{'QUERY_STRING'}; 
+        unless ($ENV{'QUERY_STRING'} eq '') {
+            $url.=(($url=~/\?/)?'&':'?').$ENV{'QUERY_STRING'};
+        }
 	# reappend the query arguments
 	$r->print(&wrapper($orgurl,$url));
     } # not just the menu
@@ -155,6 +159,33 @@ sub handler {
 1;
 __END__
 
+=pod
+
+=head1 NAME
+
+Apache::lonwrapper - External and binary file management.
+
+=head1 SYNOPSIS
+
+Wrapper for external and binary files as standalone resources. Edit handler for rat maps; TeX content handler.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 Subroutines
+
+=over
+
+=item simple_menu()
+
+=item wrapper()
+
+=item handler()
+
+=back
+
+=cut
+
 
 
 
